@@ -1,6 +1,7 @@
 from ..multiprocessing import Todo
 from ..sentry.commands import SentryCommand
 from ..elasticsearch.commands import ElasticSearchCommand
+from ..lamagram.commands import LamagramCommand
 
 
 class LogToDo(Todo):
@@ -9,3 +10,10 @@ class LogToDo(Todo):
         elastic_cmd = ElasticSearchCommand(response, status_code, index, doc, args, headers, params)
         commands = [sentry_cmd, elastic_cmd]
         super(LogToDo, self).__init__(commands)
+
+
+class LamagramToDo(Todo):
+    def __init__(self, chat_id, text, status_code):
+        lamagram_cmd = LamagramCommand(chat_id, text, status_code)
+        commands = [lamagram_cmd]
+        super(LamagramToDo, self).__init__(commands)
